@@ -16,7 +16,7 @@ class PseudocodefrStyle(Style):
         String:                 'bg:#eee #111'
     }
 
-class PseudocodefrLexer(RegexLexer, PseudocodefrStyle):
+class PseudocodefrLexer(RegexLexer):
     '''
     A Pseudo code (fr) lexer
     '''
@@ -77,9 +77,12 @@ class PseudocodefrLexer(RegexLexer, PseudocodefrStyle):
                    Name.Constant),
                   
                  # Operators
-                 (r'(<=|>=|<>|!=|<-|\^|\*|\+|-|\/|<|>|=|\\\\|mod|←|↑|→|≤|≥|≠|÷|×|\.\.|\[|\]|\.|non|xou|et|ou)',
+                 (r'(<=|>=|<>|!=|<-|\^|\*|\+|-|\/|<|>|=|\\\\|mod|←|↑|→|≤|≥|≠|÷|×|\.\.|\[|\]|\.)',
                   op_replace),
 
+                # Operator Words
+                (r'(non|xou|et|ou)', Operator.Word )
+
                  (r'(\(|\)|\,|\;|:)',
                   Punctuation),
 
